==> rapid_widgets_library-0.2.38.tar.gz: lib/custom-multiflipcard.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:rapid_widgets_library/consts.dart' as constants;
import 'dart:math';

/*
This widget takes in a list of cards and displays them by flipping them.

Imports:
import 'custom-multiflipcard.dart';


* Widget cardf1 = Container(decoration: BoxDecoration(color: Colors.black87, borderRadius: BorderRadius.all(Radius.circular(8.0)),), child: Column(children: <Widget>[Expanded(flex:1,child: Center(child: Text('El-Classico', style: TextStyle(color:Colors.white70,fontSize:24,fontWeight: FontWeight.bold),))),
          Expanded(flex: 4, child: Center(child: AspectRatio(aspectRatio: 16/9, child: Container(height: 150, decoration: BoxDecoration(image: DecorationImage(image: NetworkImage('https://images.indianexpress.com/2019/03/messi-ramos-1.jpg',),),),),),),),
          Expanded(flex:1,child:Center(child: Text('12-06-2020 1:30 A.M IST', style: TextStyle(color:Colors.yellow, fontSize:20,fontWeight: FontWeight.bold, fontStyle: FontStyle.italic),))),],),);
    Widget cardf2 = Container(decoration: BoxDecoration(color: Colors.black87, borderRadius: BorderRadius.all(Radius.circular(8.0)),), child: Column(children: <Widget>[Expanded(flex:5,child: Center(child: Text('Score Board', style: TextStyle(color:Colors.white70,fontSize:24,fontWeight: FontWeight.bold),))),
          Expanded(flex: 20, child: Center(child: Text('FCB 3:1 RM', style: TextStyle(color:Colors.yellow,fontSize:60,fontWeight: FontWeight.bold),))), Expanded(flex:3,child:Center(child: Text('Messi : 22', style: TextStyle(color:Colors.white70,fontWeight: FontWeight.bold, fontSize:14, fontStyle: FontStyle.italic),))),
          Expanded(flex:3,child:Center(child: Text('Messi : 45', style: TextStyle(color:Colors.white70,fontWeight: FontWeight.bold, fontSize:14, fontStyle: FontStyle.italic),))), Expanded(flex:3,child:Center(child: Text('Suarez : 89', style: TextStyle(color:Colors.white70,fontWeight: FontWeight.bold, fontSize:14, fontStyle: FontStyle.italic),))), Expanded(flex:3,child:Center(child: Text('Benzema : 65', style: TextStyle(color:Colors.white70,fontWeight: FontWeight.bold, fontSize:14, fontStyle: FontStyle.italic),))),],),);
    Widget cardf3 = Container(decoration: BoxDecoration(color: Colors.black87, borderRadius: BorderRadius.all(Radius.circular(8.0)),), child: Column(children: <Widget>[Expanded(flex:5,child: Center(child: Text('Trivia', style: TextStyle(color:Colors.white70,fontSize:30,fontWeight: FontWeight.bold),))), Expanded(flex: 25, child: Padding(padding: const EdgeInsets.all(8.0), child: Center(child: Text('El-Classico is the name given in football to any match between fierce rivals FC Barcelona and Real Madrid. Originally it referred only to those competitions held in the Spanish championship, but nowadays the term has been generalized, and tends to include every single match between the two clubs.', style: TextStyle(color:Colors.yellow,fontSize:18,fontWeight: FontWeight.bold),)),)),],),);
    Widget cardf4 = Container(decoration: BoxDecoration(color: Colors.black87, borderRadius: BorderRadius.all(Radius.circular(8.0)),),
      child: Column(children: <Widget>[
          Expanded(flex:5,child: Center(child: Text('Complete Stats.', style: TextStyle(color:Colors.white70,fontSize:24,fontWeight: FontWeight.bold),))),
          Expanded(flex:3,child:Center(child: Text('Total Shots: FCB-22, RM-9', style: TextStyle(color:Colors.yellow,fontWeight: FontWeight.bold, fontSize:16, fontStyle: FontStyle.italic),))),
          Expanded(flex:3,child:Center(child: Text('Possession: FCB-65%, RM-35%', style: TextStyle(color:Colors.yellow,fontWeight: FontWeight.bold, fontSize:16, fontStyle: FontStyle.italic),))),
          Expanded(flex:3,child:Center(child: Text('Fouls: FCB-10, RM-14 : 22', style: TextStyle(color:Colors.yellow,fontWeight: FontWeight.bold, fontSize:16, fontStyle: FontStyle.italic),))),
          Expanded(flex:3,child:Center(child: Text('Passes Completed: FCB-955, RM-423', style: TextStyle(color:Colors.yellow,fontWeight: FontWeight.bold, fontSize:16, fontStyle: FontStyle.italic),))),
          FlatButton(color: Colors.black, shape: new RoundedRectangleBorder(borderRadius: new BorderRadius.circular(30.0)), padding: EdgeInsets.symmetric(vertical: 4.0, horizontal: 40.0),
            //adds padding inside the button
            child: Text('View More', style: TextStyle(color: Colors.white, fontSize: 18),),
            onPressed: () => {},)],),);
    List<Widget> listofcards=[];
    listofcards.add(cardf1);listofcards.add(cardf2);listofcards.add(cardf3);listofcards.add(cardf4);
    callbackfunc(int nIndex, String sText) {print(nIndex);print(sText);}


      body: CustomFlipCard(data:listofcards, callback:callbackfunc),
*/

class CustomFlipCard extends StatefulWidget {
  final List<Widget> data;
  final Function(int, String) callback;
  final double cardwidth;
  final double cardheight;
  final int flipspeed;
  final double borderRadius;

  CustomFlipCard(
      {Key key,
      @required this.data,
      this.callback,
      this.cardwidth,
      this.cardheight,
      this.flipspeed,
      this.borderRadius})
      : super(key: key);

  @override
  _CustomFlipCard createState() => _CustomFlipCard();
}

class _CustomFlipCard extends State<CustomFlipCard> {
  Widget front;
  Widget back;
  String side;
  int count;

  @override
  void initState() {
    front = widget.data[0];
    back = widget.data[1];
    count = 1;
    widget.data.add(Container());
    super.initState();
  }

  Widget build(BuildContext context) {
    return Container(
      height: widget.cardheight == null
          ? constants.heightOneEighty * 2
          : widget.cardheight,
      width: widget.cardwidth == null
          ? constants.heightThreeHundred * 2
          : widget.cardwidth,
      decoration: BoxDecoration(
        color: Theme.of(context).accentColor,
        border: Border.all(
          color: Theme.of(context).primaryColorDark,
          width: constants.heightOne,
        ),
        borderRadius: BorderRadius.circular(widget.borderRadius == null
            ? constants.heightFive * constants.heightThree
            : widget.borderRadius),
      ),
      child: FlipCard(
          direction: FlipDirection.HORIZONTAL,
          speed: widget.flipspeed == null ? 1000 : widget.flipspeed,
          flipOnTouch: count == (widget.data.length - 1) ? false : true,
          onFlipDone: (status) {
            print(status);
            setState(() {
              print(count);
              print(widget.data.length);
              if (count != widget.data.length - 1) {
                if (status == false)
                  side = "back";
                else
                  side = "front";
                if (side == "back")
                  front = widget.data[++count];
                else if (side == "front") back = widget.data[++count];
              }
              print(count);
            });
          },
          front: front,
          back: back),
    );
  }
}

enum FlipDirection {
  VERTICAL,
  HORIZONTAL,
}

class AnimationCard extends StatelessWidget {
  AnimationCard({this.child, this.animation, this.direction});

  final Widget child;
  final Animation<double> animation;
  final FlipDirection direction;

  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
      animation: animation,
      builder: (BuildContext context, Widget child) {
        var transform = Matrix4.identity();
        transform.setEntry(3, 2, 0.001);
        if (direction == FlipDirection.VERTICAL) {
          transform.rotateX(animation.value);
        } else {
          transform.rotateY(animation.value);
        }
        return Transform(
          transform: transform,
          alignment: Alignment.center,
          child: child,
        );
      },
      child: child,
    );
  }
}

typedef void BoolCallback(bool isFront);

class FlipCard extends StatefulWidget {
  final Widget front;
  final Widget back;
  final int speed;
  final FlipDirection direction;
  final VoidCallback onFlip;
  final BoolCallback onFlipDone;
  final bool flipOnTouch;

  const FlipCard(
      {Key key,
      @required this.front,
      @required this.back,
      this.speed = 500,
      this.onFlip,
      this.onFlipDone,
      this.direction = FlipDirection.HORIZONTAL,
      this.flipOnTouch = true})
      : super(key: key);

  @override
  State<StatefulWidget> createState() {
    return FlipCardState();
  }
}

class FlipCardState extends State<FlipCard>
    with SingleTickerProviderStateMixin {
  AnimationController controller;
  Animation<double> _frontRotation;
  Animation<double> _backRotation;

  bool isFront = true;

  @override
  void initState() {
    super.initState();
    controller = AnimationController(
        duration: Duration(milliseconds: widget.speed), vsync: this);
    _frontRotation = TweenSequence(
      <TweenSequenceItem<double>>[
        TweenSequenceItem<double>(
          tween: Tween(begin: 0.0, end: pi / 2)
              .chain(CurveTween(curve: Curves.easeIn)),
          weight: 50.0,
        ),
        TweenSequenceItem<double>(
          tween: ConstantTween<double>(pi / 2),
          weight: 50.0,
        ),
      ],
    ).animate(controller);
    _backRotation = TweenSequence(
      <TweenSequenceItem<double>>[
        TweenSequenceItem<double>(
          tween: ConstantTween<double>(pi / 2),
          weight: 50.0,
        ),
        TweenSequenceItem<double>(
          tween: Tween(begin: -pi / 2, end: 0.0)
              .chain(CurveTween(curve: Curves.easeOut)),
          weight: 50.0,
        ),
      ],
    ).animate(controller);
    controller.addStatusListener((status) {
      if (status == AnimationStatus.completed ||
          status == AnimationStatus.dismissed) {
        if (widget.onFlipDone != null) widget.onFlipDone(isFront);
      }
    });
  }

  void toggleCard() {
    if (widget.onFlip != null) {
      widget.onFlip();
    }
    if (isFront) {
      controller.forward();
    } else {
      controller.reverse();
    }

    setState(() {
      isFront = !isFront;
    });
  }

  @override
  Widget build(BuildContext context) {
    final child = Stack(
      fit: StackFit.passthrough,
      children: <Widget>[
        _buildContent(front: true),
        _buildContent(front: false),
      ],
    );
    if (widget.flipOnTouch) {
      return GestureDetector(
        behavior: HitTestBehavior.translucent,
        onTap: toggleCard,
        child: child,
      );
    }
    return child;
  }

  Widget _buildContent({@required bool front}) {
    return IgnorePointer(
      ignoring: front ? !isFront : isFront,
      child: AnimationCard(
        animation: front ? _frontRotation : _backRotation,
        child: front ? widget.front : widget.back,
        direction: widget.direction,
      ),
    );
  }

  @override
  void dispose() {
    controller.dispose();
    super.dispose();
  }
}

==> rapid_widgets_library-0.2.46.tar.gz: lib/custom-multiflipcard.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:rapid_widgets_library/consts.dart' as constants;
import 'dart:math';

/*
This widget takes in a list of cards and displays them by flipping them.

Imports:
import 'custom-multiflipcard.dart';


* Widget cardf1 = Container(decoration: BoxDecoration(color: Colors.black87, borderRadius: BorderRadius.all(Radius.circular(8.0)),), child: Column(children: <Widget>[Expanded(flex:1,child: Center(child: Text('El-Classico', style: GoogleFonts.getFont('Roboto',color:Colors.white70,fontSize:24,fontWeight: FontWeight.bold),))),
          Expanded(flex: 4, child: Center(child: AspectRatio(aspectRatio: 16/9, child: Container(height: 150, decoration: BoxDecoration(image: DecorationImage(image: NetworkImage('https://images.indianexpress.com/2019/03/messi-ramos-1.jpg',),),),),),),),
          Expanded(flex:1,child:Center(child: Text('12-06-2020 1:30 A.M IST', style: GoogleFonts.getFont('Roboto',color:Colors.yellow, fontSize:20,fontWeight: FontWeight.bold, fontStyle: FontStyle.italic),))),],),);
    Widget cardf2 = Container(decoration: BoxDecoration(color: Colors.black87, borderRadius: BorderRadius.all(Radius.circular(8.0)),), child: Column(children: <Widget>[Expanded(flex:5,child: Center(child: Text('Score Board', style: GoogleFonts.getFont('Roboto',color:Colors.white70,fontSize:24,fontWeight: FontWeight.bold),))),
          Expanded(flex: 20, child: Center(child: Text('FCB 3:1 RM', style: GoogleFonts.getFont('Roboto',color:Colors.yellow,fontSize:60,fontWeight: FontWeight.bold),))), Expanded(flex:3,child:Center(child: Text('Messi : 22', style: GoogleFonts.getFont('Roboto',color:Colors.white70,fontWeight: FontWeight.bold, fontSize:14, fontStyle: FontStyle.italic),))),
          Expanded(flex:3,child:Center(child: Text('Messi : 45', style: GoogleFonts.getFont('Roboto',color:Colors.white70,fontWeight: FontWeight.bold, fontSize:14, fontStyle: FontStyle.italic),))), Expanded(flex:3,child:Center(child: Text('Suarez : 89', style: GoogleFonts.getFont('Roboto',color:Colors.white70,fontWeight: FontWeight.bold, fontSize:14, fontStyle: FontStyle.italic),))), Expanded(flex:3,child:Center(child: Text('Benzema : 65', style: GoogleFonts.getFont('Roboto',color:Colors.white70,fontWeight: FontWeight.bold, fontSize:14, fontStyle: FontStyle.italic),))),],),);
    Widget cardf3 = Container(decoration: BoxDecoration(color: Colors.black87, borderRadius: BorderRadius.all(Radius.circular(8.0)),), child: Column(children: <Widget>[Expanded(flex:5,child: Center(child: Text('Trivia', style: GoogleFonts.getFont('Roboto',color:Colors.white70,fontSize:30,fontWeight: FontWeight.bold),))), Expanded(flex: 25, child: Padding(padding: const EdgeInsets.all(8.0), child: Center(child: Text('El-Classico is the name given in football to any match between fierce rivals FC Barcelona and Real Madrid. Originally it referred only to those competitions held in the Spanish championship, but nowadays the term has been generalized, and tends to include every single match between the two clubs.', style: GoogleFonts.getFont('Roboto',color:Colors.yellow,fontSize:18,fontWeight: FontWeight.bold),)),)),],),);
    Widget cardf4 = Container(decoration: BoxDecoration(color: Colors.black87, borderRadius: BorderRadius.all(Radius.circular(8.0)),),
      child: Column(children: <Widget>[
          Expanded(flex:5,child: Center(child: Text('Complete Stats.', style: GoogleFonts.getFont('Roboto',color:Colors.white70,fontSize:24,fontWeight: FontWeight.bold),))),
          Expanded(flex:3,child:Center(child: Text('Total Shots: FCB-22, RM-9', style: GoogleFonts.getFont('Roboto',color:Colors.yellow,fontWeight: FontWeight.bold, fontSize:16, fontStyle: FontStyle.italic),))),
          Expanded(flex:3,child:Center(child: Text('Possession: FCB-65%, RM-35%', style: GoogleFonts.getFont('Roboto',color:Colors.yellow,fontWeight: FontWeight.bold, fontSize:16, fontStyle: FontStyle.italic),))),
          Expanded(flex:3,child:Center(child: Text('Fouls: FCB-10, RM-14 : 22', style: GoogleFonts.getFont('Roboto',color:Colors.yellow,fontWeight: FontWeight.bold, fontSize:16, fontStyle: FontStyle.italic),))),
          Expanded(flex:3,child:Center(child: Text('Passes Completed: FCB-955, RM-423', style: GoogleFonts.getFont('Roboto',color:Colors.yellow,fontWeight: FontWeight.bold, fontSize:16, fontStyle: FontStyle.italic),))),
          FlatButton(color: Colors.black, shape: new RoundedRectangleBorder(borderRadius: new BorderRadius.circular(30.0)), padding: EdgeInsets.symmetric(vertical: 4.0, horizontal: 40.0),
            //adds padding inside the button
            child: Text('View More', style: GoogleFonts.getFont('Roboto',color: Colors.white, fontSize: 18),),
            onPressed: () => {},)],),);
    List<Widget> listofcards=[];
    listofcards.add(cardf1);listofcards.add(cardf2);listofcards.add(cardf3);listofcards.add(cardf4);
    callbackfunc(int nIndex, String sText) {print(nIndex);print(sText);}


      body: CustomFlipCard(data:listofcards, callback:callbackfunc),
*/

class CustomFlipCard extends StatefulWidget {
  final List<Widget> data;
  final Function(int, String) callback;
  final double cardwidth;
  final double cardheight;
  final int flipspeed;
  final double borderRadius;

  CustomFlipCard(
      {Key key,
      @required this.data,
      this.callback,
      this.cardwidth,
      this.cardheight,
      this.flipspeed,
      this.borderRadius})
      : super(key: key);

  @override
  _CustomFlipCard createState() => _CustomFlipCard();
}

class _CustomFlipCard extends State<CustomFlipCard> {
  Widget front;
  Widget back;
  String side;
  int count;

  @override
  void initState() {
    front = widget.data[0];
    back = widget.data[1];
    count = 1;
    widget.data.add(Container());
    super.initState();
  }

  Widget build(BuildContext context) {
    return Container(
      height: widget.cardheight == null
          ? constants.heightOneEighty * 2
          : widget.cardheight,
      width: widget.cardwidth == null
          ? constants.heightThreeHundred * 2
          : widget.cardwidth,
      decoration: BoxDecoration(
        color: Theme.of(context).accentColor,
        border: Border.all(
          color: Theme.of(context).primaryColorDark,
          width: constants.heightOne,
        ),
        borderRadius: BorderRadius.circular(widget.borderRadius == null
            ? constants.heightFive * constants.heightThree
            : widget.borderRadius),
      ),
      child: FlipCard(
          direction: FlipDirection.HORIZONTAL,
          speed: widget.flipspeed == null ? 1000 : widget.flipspeed,
          flipOnTouch: count == (widget.data.length - 1) ? false : true,
          onFlipDone: (status) {
            print(status);
            setState(() {
              print(count);
              print(widget.data.length);
              if (count != widget.data.length - 1) {
                if (status == false)
                  side = "back";
                else
                  side = "front";
                if (side == "back")
                  front = widget.data[++count];
                else if (side == "front") back = widget.data[++count];
              }
              print(count);
            });
          },
          front: front,
          back: back),
    );
  }
}

enum FlipDirection {
  VERTICAL,
  HORIZONTAL,
}

class AnimationCard extends StatelessWidget {
  AnimationCard({this.child, this.animation, this.direction});

  final Widget child;
  final Animation<double> animation;
  final FlipDirection direction;

  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
      animation: animation,
      builder: (BuildContext context, Widget child) {
        var transform = Matrix4.identity();
        transform.setEntry(3, 2, 0.001);
        if (direction == FlipDirection.VERTICAL) {
          transform.rotateX(animation.value);
        } else {
          transform.rotateY(animation.value);
        }
        return Transform(
          transform: transform,
          alignment: Alignment.center,
          child: child,
        );
      },
      child: child,
    );
  }
}

typedef void BoolCallback(bool isFront);

class FlipCard extends StatefulWidget {
  final Widget front;
  final Widget back;
  final int speed;
  final FlipDirection direction;
  final VoidCallback onFlip;
  final BoolCallback onFlipDone;
  final bool flipOnTouch;

  const FlipCard(
      {Key key,
      @required this.front,
      @required this.back,
      this.speed = 500,
      this.onFlip,
      this.onFlipDone,
      this.direction = FlipDirection.HORIZONTAL,
      this.flipOnTouch = true})
      : super(key: key);

  @override
  State<StatefulWidget> createState() {
    return FlipCardState();
  }
}

class FlipCardState extends State<FlipCard>
    with SingleTickerProviderStateMixin {
  AnimationController controller;
  Animation<double> _frontRotation;
  Animation<double> _backRotation;

  bool isFront = true;

  @override
  void initState() {
    super.initState();
    controller = AnimationController(
        duration: Duration(milliseconds: widget.speed), vsync: this);
    _frontRotation = TweenSequence(
      <TweenSequenceItem<double>>[
        TweenSequenceItem<double>(
          tween: Tween(begin: 0.0, end: pi / 2)
              .chain(CurveTween(curve: Curves.easeIn)),
          weight: 50.0,
        ),
        TweenSequenceItem<double>(
          tween: ConstantTween<double>(pi / 2),
          weight: 50.0,
        ),
      ],
    ).animate(controller);
    _backRotation = TweenSequence(
      <TweenSequenceItem<double>>[
        TweenSequenceItem<double>(
          tween: ConstantTween<double>(pi / 2),
          weight: 50.0,
        ),
        TweenSequenceItem<double>(
          tween: Tween(begin: -pi / 2, end: 0.0)
              .chain(CurveTween(curve: Curves.easeOut)),
          weight: 50.0,
        ),
      ],
    ).animate(controller);
    controller.addStatusListener((status) {
      if (status == AnimationStatus.completed ||
          status == AnimationStatus.dismissed) {
        if (widget.onFlipDone != null) widget.onFlipDone(isFront);
      }
    });
  }

  void toggleCard() {
    if (widget.onFlip != null) {
      widget.onFlip();
    }
    if (isFront) {
      controller.forward();
    } else {
      controller.reverse();
    }

    setState(() {
      isFront = !isFront;
    });
  }

  @override
  Widget build(BuildContext context) {
    final child = Stack(
      fit: StackFit.passthrough,
      children: <Widget>[
        _buildContent(front: true),
        _buildContent(front: false),
      ],
    );
    if (widget.flipOnTouch) {
      return GestureDetector(
        behavior: HitTestBehavior.translucent,
        onTap: toggleCard,
        child: child,
      );
    }
    return child;
  }

  Widget _buildContent({@required bool front}) {
    return IgnorePointer(
      ignoring: front ? !isFront : isFront,
      child: AnimationCard(
        animation: front ? _frontRotation : _backRotation,
        child: front ? widget.front : widget.back,
        direction: widget.direction,
      ),
    );
  }

  @override
  void dispose() {
    controller.dispose();
    super.dispose();
  }
}
